@@ -30,13 +30,14 @@
 
 /*!
 	\file
-	\version \$Id: EbmlBinary.cpp 1112 2005-03-28 09:55:50Z mosu $
+	\version \$Id: EbmlBinary.cpp 520 2010-08-19 12:01:28Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Julien Coloos	<suiryc @ users.sf.net>
 */
 #include <cassert>
 
 #include "ebml/EbmlBinary.h"
+#include "ebml/StdIOCallback.h"
 
 START_LIBEBML_NAMESPACE
 
@@ -61,6 +62,9 @@ EbmlBinary::~EbmlBinary(void) {
 		free(Data);
 }
 
+EbmlBinary::operator const binary &() const {return *Data;}
+
+
 filepos_t EbmlBinary::RenderData(IOCallback & output, bool bForceRender, bool bWithDefault)
 {
 	output.writeFully(Data,GetSize());
@@ -81,14 +85,15 @@ filepos_t EbmlBinary::ReadData(IOCallback & input, ScopeMode ReadFully)
 	if (Data != NULL)
 		free(Data);
 	
-	if (ReadFully == SCOPE_NO_DATA)
+    if (ReadFully == SCOPE_NO_DATA || !GetSize())
 	{
 		Data = NULL;
 		return GetSize();
 	}
 
 	Data = (binary *)malloc(GetSize() * sizeof(binary));
-	assert(Data != NULL);
+    if (Data == NULL)
+        throw CRTError("Error allocating data");
 	SetValueIsSet();
 	return input.read(Data, GetSize());
 }
